@@ -162,6 +162,27 @@ class CreateDefaultFileSystemItemsAction(flow.Action):
         self._department.files.touch()
 
 
+class ContextualEnv(flow.Object):
+
+    department = flow.Parent(2)
+    environment = flow.Child(ContextualView)
+
+
+class GotoContextualEnv(flow.Action):
+
+    _department = flow.Parent()
+
+    def needs_dialog(self):
+        return False
+    
+    def allow_context(self, context):
+        return context and context.endswith('.inline')
+    
+    def run(self, button):
+        oid = self._department.contextual_env.oid()
+        return self.get_result(goto=oid)
+
+
 class Department(flow.Object):
 
     _parent = flow.Parent()
@@ -169,6 +190,7 @@ class Department(flow.Object):
     toggle_bookmark = flow.Child(ToggleBookmarkAction)
 
     settings = flow.Child(ContextualView).ui(hidden=True)
+    contextual_env = flow.Child(ContextualEnv).ui(hidden=True)
     files = (
         flow.Child(FileSystemMap)
         .injectable()
@@ -179,6 +201,7 @@ class Department(flow.Object):
     create_defaults = flow.Child(CreateDefaultFileSystemItemsAction).ui(
         label="Create default files"
     )
+    show_environment = flow.Child(GotoContextualEnv)
     path = flow.Computed(cached=True).ui(hidden=True)
 
     def get_default_contextual_edits(self, context_name):
@@ -187,6 +210,10 @@ class Department(flow.Object):
                 department=self.name(),
                 context=self._parent.__class__.__name__.lower(),
             )
+
+    def get_contextual_view(self, context_name):
+        if context_name == 'environment':
+            return self.contextual_env.environment
     
     def compute_child_value(self, child_value):
         if child_value is self.path:
