@@ -81,21 +81,23 @@ class EditFileRunner(Runner):
     def show_terminal(self):
         return False
 
-    def exec_env_var(self):
-        return "%s_EXEC_PATH" % self.__class__.__name__.upper()
+    def exec_env_var(self, version=None):
+        key = self.__class__.__name__.upper()
+
+        if version is not None:
+            key += '_%s' % version.upper().replace('.', '_')
+        
+        return '%s_EXEC_PATH' % key
 
     def executable(self):
-        exec_var = self.exec_env_var()
-
-        if self.version:
-            exec_var += "_%s" % self.version.replace(".", "_")
-
         try:
-            print('[RUNNER] exec path: ', os.environ[exec_var])
-            return os.environ[exec_var]
+            exec_path = os.environ[self.exec_env_var(self.version)]
+            print('[RUNNER] exec path: ', exec_path)
+            return exec_path
         except KeyError:
-            print('[RUNNER] exec path: ', os.environ[self.exec_env_var()])
-            return os.environ[self.exec_env_var()]
+            exec_path = os.environ[self.exec_env_var()]
+            print('[RUNNER] exec path: ', exec_path)
+            return exec_path
 
 
 class ImageMagick(EditFileRunner):
@@ -122,7 +124,7 @@ class Blender(EditFileRunner):
 
     @classmethod
     def supported_versions(cls):
-        return ["2.83", "2.90", "2.91"]
+        return ["2.83", "2.90", "2.91", "2.92", "2.93"]
 
     @classmethod
     def supported_extensions(cls):
@@ -298,7 +300,7 @@ class RunnerVersionChoiceValue(flow.values.ChoiceValue):
         if not runner_versions:
             runner_versions = []
 
-        return runner_versions
+        return ['default'] + runner_versions
 
 
 class ChangeDefaultRunner(flow.Action):
@@ -332,20 +334,6 @@ class ChangeDefaultRunner(flow.Action):
             self.root().session().log_debug("Application not recognized")
             return self.get_result(close=False)
 
-        runner_versions = factory.get_runner_versions(self.application.get())
-
-        if (
-            self.version.get()
-            and runner_versions
-            and not str(self.version.get()) in runner_versions
-        ):
-            self.root().session().log_debug(
-                "Version {version} of {app} unknown".format(
-                    version=self.version.get(), app=self.application.get()
-                )
-            )
-            return self.get_result(close=False)
-
         self._extension.runner_name.set(self.application.get())
         self._extension.runner_version.set(self.version.get())
         self._extension.touch()
