@@ -1688,9 +1688,13 @@ class MultiRequestedRevisions(RequestedRevisions):
     }
     
     request_action = flow.Parent()
+    source_sites = flow.SessionParam([]).ui(hidden=True)
     
     def columns(self):
-        return ['Revision'] + self.request_action.sites.target_sites.get()
+        site_names = self.request_action.sites.target_sites.get() + self.source_sites.get()
+        site_names = list(dict.fromkeys(site_names))
+
+        return ['Revision'] + site_names
     
     def _fill_row_cells(self, row, item):
         row['Revision'] = item.oid()
@@ -1705,7 +1709,10 @@ class MultiRequestedRevisions(RequestedRevisions):
             style['Revision_icon'] = self.STYLE_BY_STATUS['Undefined'][1]
             return
         
-        for site_name in self.request_action.sites.target_sites.get():
+        site_names = self.request_action.sites.target_sites.get() + self.source_sites.get()
+        site_names = list(dict.fromkeys(site_names))
+
+        for site_name in site_names:
             status = item.get_sync_status(site_name=site_name)
             style[site_name + '_icon'] = self.STYLE_BY_STATUS[status][1]
 
@@ -1743,6 +1750,13 @@ class MultiRequestRevisions(RequestRevisions):
             self.revisions.oids.revert_to_default()
             oids = self._get_oid(self.pattern.get())
             self.revisions.oids.set(oids)
+
+            source_sites = []
+            for oid in oids:
+                site_name = self.root().session().cmds.Flow.get_value(oid + '/site')
+                source_sites.append(site_name)
+            
+            self.revisions.source_sites.set(source_sites)
             self.revisions.touch()
             
             return self.get_result(close=False)
