@@ -309,8 +309,8 @@ class AddEnvVarAction(flow.Action):
 
     _env = flow.Parent()
 
-    var_name = flow.Param("").ui(label="Name")
-    var_value = flow.Param("").ui(label="Value")
+    var_name = flow.SessionParam("").ui(label="Name")
+    var_value = flow.SessionParam("").ui(label="Value")
 
     def get_buttons(self):
         return ["Add", "Cancel"]
@@ -345,6 +345,8 @@ class AddEnvVarAction(flow.Action):
 
         #os.environ[self.var_name.get()] = self.var_value.get()
         self._env.touch()
+        self.var_name.revert_to_default()
+        self.var_value.revert_to_default()
 
 
 class ChangeEnvVarValueAction(flow.Action):
